@@ -18,6 +18,7 @@
 
 #include <kiconloader.h>
 #include <klocale.h>
+#include <ksystemtray.h>
 #include <ktoolbarbutton.h>
 
 #include <qtimer.h>
@@ -44,11 +45,14 @@ Kpopup::Kpopup() {
     toolbar -> show();
     statusbar -> show();
     addToolBar(toolbar);
-    setStatusBar(statusbar);
 
     setStatusText(i18n("Welcome to KPopup ") + QString(VERSION));
     timer -> start(3000, TRUE);
 
+    tray = new KSystemTray(this);
+    tray -> setPixmap(kapp -> miniIcon());
+    tray -> show();
+
     lbl_Sender = new QLabel(i18n("Popup from:"), this);
     lbl_Sender -> setGeometry(12, 38, 88, 20);
     lbl_Sender -> setAlignment(AlignTop | AlignLeft);
@@ -308,3 +312,13 @@ void Kpopup::deletePopup() {
 
     showPopup();
 }
+
+/*
+ * hide event from KMainWindow
+ */
+void Kpopup::hideEvent(QHideEvent *e) {
+
+    KMainWindow::hideEvent(e);
+    tray -> show();
+    hide();
+}
