@@ -22,15 +22,16 @@
 #endif
 
 #include <kapp.h>
+#include <kmainwindow.h>
 #include <kstatusbar.h>
-#include <ktmainwindow.h>
+#include <ksystemtray.h>
 #include <ktoolbar.h>
 
 #include <qdatetime.h>
 #include <qmap.h>
 #include <qtextview.h>
 
-class Kpopup : public KTMainWindow {
+class Kpopup : public KMainWindow {
     Q_OBJECT
 
     public:
@@ -41,6 +42,9 @@ class Kpopup : public KTMainWindow {
             void setStatusText(const char *);
             void signalNewMessage();
 
+    protected:
+            void hideEvent(QHideEvent *); // hide event
+
     private slots:
             void commandCallback(int);
             void timerDone();
@@ -55,6 +59,7 @@ class Kpopup : public KTMainWindow {
 
             KStatusBar *statusbar;
             KToolBar *toolbar;
+            KSystemTray *tray;
             QLabel *lbl_Sender;
             QLabel *lbl_SenderValue;
             QLabel *lbl_DateTime;
