@@ -2,7 +2,7 @@
                           misc.h  -  description
                           ----------------------
     copyright            : (C) 2000 by Torsten Henschel
-    email                : henschel@fh-brandenburg.de
+    email                : thenschel@henschelsoft.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -17,9 +17,22 @@
 #ifndef MISC_H
 #define MISC_H
 
-//Path of smbclient
-#define SMBPATH "/usr/bin"
+#include "kpopup.h"
 
-char *File_read(const char *Filename);
+#undef DEBUG
+#define SMBPATH "/usr/bin" //Path of smbclient
+#define TMPPOPUPFILE "/tmp/kpopup-message"
+#define SETSIG(sig, fun, fla)	sa.sa_handler = fun; \
+    sa.sa_flags = fla; \
+    sigaction(sig, &sa, NULL)
+
+void fileCopy(const char *, const char *);
+void signalSetup();
+void signalMessage(int);
+void sendSignalForNewMessage();
+char *readSender();
+char *readPopupText();
+
+extern Kpopup *w;
 
 #endif
